pub struct NetworkStatusUnverified {
body: NetworkStatus,
pub sigs: SignaturesData<NetworkStatusUnverified>,
}Expand description
Signed (unverified) form of NetworkStatus
Embodies:
NetworkStatus: document bodyNetworkStatusSignatures: signatures
If this type was parsed from a document text, the signatures have not yet been verified.
Use a .verify_... method to obtain useable, verified, contents.
Fields
body: NetworkStatusThe actual body
sigs: SignaturesData<NetworkStatusUnverified>Signatures
Implementations
Sourceimpl NetworkStatusUnverified
impl NetworkStatusUnverified
Sourcepub fn can_verify(
&self,
trusted_authorities: &[RsaIdentity],
certs_already: &[AuthCert],
) -> Result<(), ConsensusVerifiabilityError>
pub fn can_verify( &self, trusted_authorities: &[RsaIdentity], certs_already: &[AuthCert], ) -> Result<(), ConsensusVerifiabilityError>
Could we verify this consensus or do we need more authcerts?
Ok means that we have enough authcerts to verify the signature.
Err means that we have not enough authcerts,
or the consensus has not enough signatures.
The ConsensusVerifiabilityError error gives the details.
Sourcepub fn verify(
self,
trusted_authorities: &[RsaIdentity],
certs: &[AuthCert],
) -> Result<TimerangeBound<NetworkStatus>, ConsensusVerifyFailed>
pub fn verify( self, trusted_authorities: &[RsaIdentity], certs: &[AuthCert], ) -> Result<TimerangeBound<NetworkStatus>, ConsensusVerifyFailed>
Verify the signatures
Doesn’t check the validity period:
the document is wrapped in TimerangeBound,
ensuring that the caller does that check.
Sourcefn verify_general<E>(
sigs: &SignaturesData<Self>,
trusted: &[RsaIdentity],
certs: &[AuthCert],
do_verify: impl Fn(ConsensusSignatureToVerify<'_>) -> Result<SignatureVerifiedIfIntended, E>,
) -> Result<(), E>where
ConsensusVerifiabilityError: Into<E>,
fn verify_general<E>(
sigs: &SignaturesData<Self>,
trusted: &[RsaIdentity],
certs: &[AuthCert],
do_verify: impl Fn(ConsensusSignatureToVerify<'_>) -> Result<SignatureVerifiedIfIntended, E>,
) -> Result<(), E>where
ConsensusVerifiabilityError: Into<E>,
Glue to call SignatureGroup::verify_general given our SignaturesData
SignatureGroup::verify_general contains the actual verification code,
shared between the old parser and the new.