UnvalidatedPlainConsensus

Type Alias UnvalidatedPlainConsensus 

pub type UnvalidatedPlainConsensus = UnvalidatedConsensus;
An PlainConsensus that has been parsed and checked for timeliness, but not for signatures.

Aliased Type

pub struct UnvalidatedPlainConsensus {
    pub consensus: Consensus,
    pub siggroup: SignatureGroup,
    pub n_authorities: Option<usize>,
}

Fields

consensus: Consensus

The consensus object. We don’t want to expose this until it’s validated.

siggroup: SignatureGroup

The signatures that need to be validated before we can call this consensus valid.

n_authorities: Option<usize>

The total number of authorities that we believe in. We need this information in order to validate the signatures, since it determines how many signatures we need to find valid in siggroup.