pub struct Preamble {
pub consensus_methods: ConsensusMethods,
pub consensus_method: NotPresent,
pub published: (Iso8601TimeSp,),
pub lifetime: Lifetime,
pub voting_delay: Option<(u32, u32)>,
pub client_versions: Vec<String>,
pub server_versions: Vec<String>,
pub known_flags: DocRelayFlags,
pub proto_statuses: Arc<ProtoStatuses>,
pub params: NetParams<i32>,
pub shared_rand_previous_value: Option<SharedRandStatus>,
pub shared_rand_current_value: Option<SharedRandStatus>,
/* private fields */
}Expand description
The preamble of a network status document, except for the intro and vote-status items.
https://spec.torproject.org/dir-spec/consensus-formats.html#section:preable
Does not include network-status-version and vote-status.
In the old parser this is not represented directly;
instead, in Consensus.flavor, there’s just the ConsensusFlavor.
parse2 doesn’t (currently) support subdocuments which contain the parent’s intro item
(ie, #[deftly(netdoc(flatten))] is not supported on the first field.)
Fields
consensus_methods: ConsensusMethodsConsensus methods supported by this voter.
consensus_method: NotPresentWhat “method” was used to produce this consensus? (A consensus method is a version number used by authorities to upgrade the consensus algorithm.)
published: (Iso8601TimeSp,)Publication time (of a vote)
lifetime: LifetimeOver what time is this consensus valid? (For votes, this is the time over which the voted-upon consensus should be valid.)
voting_delay: Option<(u32, u32)>How long in seconds should voters wait for votes and signatures (respectively) to propagate?
client_versions: Vec<String>List of recommended Tor client versions.
server_versions: Vec<String>List of recommended Tor relay versions.
known_flags: DocRelayFlagsRouter flags which could be determined
proto_statuses: Arc<ProtoStatuses>Lists of recommended and required subprotocols.
{recommended,required}-{client,relay}-protocols
params: NetParams<i32>Declared parameters for tunable settings about how to the network should operator. Some of these adjust timeouts and whatnot; some features things on and off.
Global shared-random value for the previous shared-random period.
Global shared-random value for the current shared-random period.