pub struct RouterStatusIntroItemConstructor {
pub nickname: Nickname,
pub identity: Base64Fingerprint,
pub doc_digest: FixedB64<DOC_DIGEST_LEN>,
pub publication: Iso8601TimeSp,
pub ip: Ipv4Addr,
}Expand description
Constructor (required fields) for RouterStatusIntroItem
This constructor struct contains precisely the required fields.
You can make a RouterStatusIntroItem out of it with .construct(),
or the From impl,
and use the result as a basis for further modifications.
Example
ⓘ
let router_status_intro_item = RouterStatusIntroItem {
or_port: /* optional field value */,
dir_port: /* optional field value */,
__non_exhaustive: /* optional field value */,
..RouterStatusIntroItemConstructor {
nickname: /* required field value */,
identity: /* required field value */,
doc_digest: /* required field value */,
publication: /* required field value */,
ip: /* required field value */,
}.construct()
};Fields
nickname: NicknameThe nickname for this relay.
Nicknames can be used for convenience purpose, but no more: there is no mechanism to enforce their uniqueness.
identity: Base64FingerprintFingerprint of the old-style RSA identity for this relay.
doc_digest: FixedB64<DOC_DIGEST_LEN>Digest of the document for this relay (except md consensuses)
publication: Iso8601TimeSpPublication time.
ip: Ipv4AddrIPv4 address
Implementations
Sourceimpl RouterStatusIntroItemConstructor
impl RouterStatusIntroItemConstructor
Sourcepub fn construct(self) -> RouterStatusIntroItem
pub fn construct(self) -> RouterStatusIntroItem
Construct a minimal RouterStatusIntroItem
In the returned RouterStatusIntroItem,
optional fields all get the default values.