pub type UnvalidatedPlainConsensus = UnvalidatedConsensus;Expand description
An PlainConsensus that has been parsed and checked for timeliness, but not for signatures.
Aliased Type
pub struct UnvalidatedPlainConsensus {
pub consensus: Consensus,
pub siggroup: SignatureGroup,
pub n_authorities: Option<usize>,
}Fields
consensus: ConsensusThe consensus object. We don’t want to expose this until it’s validated.
siggroup: SignatureGroupThe signatures that need to be validated before we can call this consensus valid.
The total number of authorities that we believe in. We need
this information in order to validate the signatures, since it
determines how many signatures we need to find valid in siggroup.